@@ -1,8 +1,12 @@
 from __future__ import annotations
 
-from wexample_config.const.types import DictConfig
+from typing import TYPE_CHECKING
+
 from wexample_wex_addon_dev_php.workdir.php_workdir import PhpWorkdir
 
+if TYPE_CHECKING:
+    from wexample_config.const.types import DictConfig
+
 
 class PhpLaravelWorkdir(PhpWorkdir):
     def prepare_value(self, raw_value: DictConfig | None = None) -> DictConfig:
